@@ -44,8 +44,8 @@
 #include <kio/ioslave_defaults.h>
 
 #ifdef Q_OS_WIN
-#include <experimental/filesystem>  // for permissions
-using namespace std::experimental::filesystem;
+#include <filesystem>  // for permissions
+using namespace std::filesystem;
 #include <qplatformdefs.h>
 #else
 #include <utime.h>
@@ -253,7 +253,7 @@ void SFTPInternal::log_callback(int priority, const char *function, const char *
 
 Result SFTPInternal::init()
 {
-    qCDebug(KIO_SFTP_LOG) << "pid = " << getpid();
+    qCDebug(KIO_SFTP_LOG) << "pid = " << qApp->applicationPid();
     qCDebug(KIO_SFTP_LOG) << "debug = " << getenv("KIO_SFTP_LOG_VERBOSITY");
 
     // Members are 'value initialized' to zero because of non-user defined ()!
@@ -427,6 +427,7 @@ bool SFTPInternal::createUDSEntry(const QString &filename, const QByteArray &pat
     uint64_t size = 0U;
 
     Q_ASSERT(entry.count() == 0);
+    entry.reserve(10);
 
     sftp_attributes sb = sftp_lstat(mSftp, path.constData());
     if (sb == nullptr) {
@@ -547,7 +548,7 @@ SFTPInternal::SFTPInternal(SFTPSlave *qptr)
 }
 
 SFTPInternal::~SFTPInternal() {
-    qCDebug(KIO_SFTP_LOG) << "pid = " << getpid();
+    qCDebug(KIO_SFTP_LOG) << "pid = " << qApp->applicationPid();
     closeConnection();
 
     delete mCallbacks;
@@ -2242,6 +2243,7 @@ Result SFTPInternal::listDir(const QUrl &url)
         }
 
         entry.clear();
+        entry.reserve(10);
         entry.fastInsert(KIO::UDSEntry::UDS_NAME, QFile::decodeName(dirent->name));
 
         if (dirent->type == SSH_FILEXFER_TYPE_SYMLINK) {
